import setAttributes from '../utils/setAttributes';
import normalizeColor from '../utils/normalizeColor';

/**
 * Create SVGTextElement from an annotation definition.
 * This is used for anntations of type `textbox`.
 *
 * @param {Object} a The annotation definition
 * @return {SVGTextElement} A text to be rendered
 */
export default function renderText(a) {
  // Text should be rendered at 0 degrees relative to
  // document rotation
  let text = window.document.createElementNS('http://www.w3.org/2000/svg', 'text');
  setAttributes(text, {
    x: a.x,
    y: a.y,
    fill: normalizeColor(a.color || '#000'),
    fontSize: a.size,
    transform: `rotate(${a.rotation})`,
    style: 'white-space: pre',
    filter: 'url(#solid)'
  });
  text.innerHTML = a.content;

  // CODE POUR BACKGROUND TEXTE
  var defs = window.document.createElementNS("http://www.w3.org/2000/svg", "defs");
  var filter = window.document.createElementNS("http://www.w3.org/2000/svg", "filter");
    filter.setAttribute("id","f1");
    filter.setAttribute("x","0");
    filter.setAttribute("y","0");
  var flood = window.document.createElementNS("http://www.w3.org/2000/svg", "feFlood");
    flood.setAttribute("flood-color","rgba(255, 252, 208, 0.95)");
    flood.setAttribute("result","bg");
  var merge = window.document.createElementNS("http://www.w3.org/2000/svg", "feMerge");
  var mergeNode1 = window.document.createElementNS("http://www.w3.org/2000/svg", "feMergeNode");
    mergeNode1.setAttribute('in', 'bg')

  var mergeNode2 = window.document.createElementNS("http://www.w3.org/2000/svg", "feMergeNode");
    mergeNode2.setAttribute('in', 'SourceGraphic')
  // FIN CODE POUR BACKGROUND TEXTE

  let g = window.document.createElementNS('http://www.w3.org/2000/svg', 'g');
  g.appendChild(text);
  merge.appendChild(mergeNode1);
  merge.appendChild(mergeNode2);
  filter.appendChild(flood);
  filter.appendChild(merge);
  defs.appendChild(filter);
  g.appendChild(defs);
  text.setAttribute("filter","url(#f1)");

  // g.appendChild(rect);
  return g;
}
